@@ -118,6 +118,7 @@ void pfshdrcalibrate( int argc, char* argv[] )
   int           opt_maxresponse               = -1;
   int           opt_minresponse               = -1;
   unsigned long mitsunaga_sample_no           = MITSUNAGA_SAMPLES_NO;
+  bool		opt_deghosting = false;
   
   /* helper */
   int c;
@@ -126,7 +127,6 @@ void pfshdrcalibrate( int argc, char* argv[] )
     { "help", no_argument, NULL, 'h' },
     { "verbose", no_argument, NULL, 'v' },
     { "luminance", no_argument, NULL, 'Y' },
-    //{ "fillin-response", no_argument, NULL, 'F' },      /* todo: remove - Robertson does not work well anyway */
     { "method", required_argument, NULL, 'c' },
     { "gauss", required_argument, NULL, 'g' },
     { "max-response", required_argument, NULL, 'A' },
@@ -137,13 +137,14 @@ void pfshdrcalibrate( int argc, char* argv[] )
     { "multiplier", required_argument, NULL, 'm' },
     { "bpp", required_argument, NULL, 'b' },
     { "samples", required_argument, NULL, 'p' },	
+    { "deghosting", no_argument, NULL, 'd' },	
     { NULL, 0, NULL, 0 }
   };
 
   int optionIndex = 0;
   while( ( c =  getopt_long( argc, 
 			     argv, 
-			     "hvYFc:g:r:f:s:m:b:p:x", 
+			     "hvYc:g:r:f:s:m:b:p:xd", 
 			     cmdLineOptions, 
 			     &optionIndex) ) 
 	 != -1 ) 
@@ -266,6 +267,10 @@ void pfshdrcalibrate( int argc, char* argv[] )
 	  if( opt_minresponse<0 )
 	    throw pfs::Exception("min response should be >0");
 	  break;
+	  
+	case 'd':
+		opt_deghosting = true;
+		break;
 
 	case '?':
 	  throw QuietException();
@@ -400,6 +405,11 @@ void pfshdrcalibrate( int argc, char* argv[] )
       if( iso_str != NULL )
         iso = atof( iso_str );      
 
+	float aperture = 1.f;      
+    const char* aperture_str = frame -> getTags() -> getString("aperture");
+    if( aperture_str != NULL )
+        aperture = atof( aperture_str );      
+	
       float raw_exposure_time = 1.f;      
       const char* etime_str = 
 	frame -> getTags() -> getString("exposure_time");
@@ -412,7 +422,9 @@ void pfshdrcalibrate( int argc, char* argv[] )
       // cameras. to control absolute calibration modify iso values in
       // hdrgen script or use pfsabsolute program.
       exp_time /= 1.0592f * 11.4f / 3.125f;
+	  
       VERBOSE_STR << "Exposure:" << exp_time << endl;	
+      VERBOSE_STR << "Aperture:" << aperture << endl;	
 
       // frame size
       width  = Y -> getCols();
@@ -426,8 +438,12 @@ void pfshdrcalibrate( int argc, char* argv[] )
 	  
 	  Exposure eY;
 	  eY.ti = exp_time;          
-          eY.exposure_time = raw_exposure_time;          
-          eY.iso = iso;          
+	  // The exposure times reported in the EXIF header, such as 1/40, are inaccurate and are 
+	  // only meant to be instructive to photographers. More accurate exposure time is given when
+	  // the EXIF number is rounded to the nearest 1/3 in log-2 units (nearest 1/3 of f-stop). 
+      eY.exposure_time = powf( 2, roundf(log2f(raw_exposure_time)*3.f)/3.f);
+      eY.iso = iso;          
+	  eY.aperture = aperture;
 	  eY.yi = new pfs::Array2DImpl( width, height );
 	  
 	  if( eY.yi == NULL )
@@ -461,6 +477,7 @@ void pfshdrcalibrate( int argc, char* argv[] )
 	Exposure eR,eG,eB;
 	eR.ti = eG.ti = eB.ti = exp_time;
 	eR.iso = eG.iso = eB.iso = iso;
+	eR.aperture = eG.aperture = eB.aperture = aperture;
         eR.exposure_time = eG.exposure_time = eB.exposure_time = raw_exposure_time;          
 	eR.yi = new pfs::Array2DImpl( width, height );
 	eG.yi = new pfs::Array2DImpl( width, height );
@@ -782,7 +799,7 @@ void pfshdrcalibrate( int argc, char* argv[] )
               const float *resp_curves[] = { Ir, Ig, Ib };
               
               VERBOSE_STR << "applying response to RGB channels..." << endl;
-	      sp = robertson02_applyResponseRGB( RGB_out, exposures, resp_curves, w, M);
+	      sp = robertson02_applyResponseRGB( RGB_out, exposures, resp_curves, w, M, opt_deghosting );
 
 /*                                            
               VERBOSE_STR << "applying response to R channel..." << endl;
