@@ -71,13 +71,17 @@ float corr_vec3( float *a, float *b )
   return cov / sqrt(sa * sb);  
 }
 
-
+float get_exposure_compensation( const Exposure &ex )
+{
+  return ex.exposure_time * ex.aperture*ex.aperture * ex.iso/3.125f / (1.0592f * 11.4f / 3.125f);
+}
 
 int robertson02_applyResponseRGB( pfs::Array2D *rgb_out[],         
   const ExposureList *imgs[], 
   const float *resp_curve[], 
   const float *weights, 
-  int M )
+  int M,
+  bool deghosting )
 {
   // number of exposures
   int N = imgs[0]->size();
@@ -103,9 +107,13 @@ int robertson02_applyResponseRGB( pfs::Array2D *rgb_out[],
 
     // TODO: Estimate read-out noise and use for exposure weighting
     // TODO: Better blending if difference is weights is high
-    ew[i] = ex.exposure_time; // This is a noise-optimum estimate assuming no read-out noise    
+	
+    // This is a noise-optimial reconstruction assuming that the input is affected only
+    // by the photon noise (no read-out noise), which is most often the case
+    ew[i] = ex.exposure_time; 
       
-    fprintf( stderr, "Ex: %d, t: %g iso: %g weight: %g\n", i, ex.exposure_time, ex.iso, ew[i] );    
+    VERBOSE_STR << "Ex: " << i << " exp. time: " << ex.exposure_time << "\t iso: " << ex.iso 
+                << "\t aperture: " <<  ex.aperture << "\t weight: " << ew[i] << std::endl;
   }
 
   float X[3*N];
@@ -117,93 +125,100 @@ int robertson02_applyResponseRGB( pfs::Array2D *rgb_out[],
 //    cerr << "i = " << i << "; weight = " << weights[i] << endl;  
   
   // For each pixel
+  int skipped_deghost = 0;
   for( int j = 0; j < width * height; j++ )
   {
     
     bool saturatedRGB[3] = { false, false, false };
-    float best_mw = -1;  
-    int ref = -1;
-    
-    for( int i = 0 ; i < N ; i++ )
-    {
-      saturated_exp[i] = false;
-      skip_exp[i] = false;      
-      for( int cc=0; cc < 3; cc++ )
-      {
-        const Exposure &ex = (*imgs[cc])[i];          
-        float ti = ex.ti;
-        
-        int   m  = (int) (*ex.yi)( j );
-        X[i*3+cc] = resp_curve[cc][ m ] / ti;
-        w[cc][i] = weights [ m ] * ew[i];
 
-        saturated_exp[i] |= ( m <= 1 || m >= M-2 );        
+    float best_mw = -1;  
+    int ref = -1;    
+	
+    if( deghosting ) {
+      
+      // Deghosting - find the exposure that could be used as a reference
+      for( int i = 0 ; i < N ; i++ )
+      {
+        saturated_exp[i] = false;
+        for( int cc=0; cc < 3; cc++ )
+        {
+          const Exposure &ex = (*imgs[cc])[i];          
+          float ti = get_exposure_compensation( ex );
+        
+          int   m  = (int) (*ex.yi)( j );
+          X[i*3+cc] = resp_curve[cc][ m ] / ti;
+          w[cc][i] = weights [ m ] * ew[i];
+
+          saturated_exp[i] |= ( m <= 1 || m >= M-2 );        
         
 //        cerr << X[i*3+cc] << ", ";        
 
-      }
-      float mw = (w[0][i] + w[1][i] + w[2][i])/3.f;
-      if( mw > best_mw && !saturated_exp[i] ) {
-        best_mw = mw;
-        ref = i;        
-      }      
-//      cerr << " ; ";      
-    }
-    
-//    cerr << endl;
-//    cerr << ref << ", ";
-    
-//    ref = 4;
-
-    // compute correlation with the reference
-    if( ref != -1 && !saturated_exp[ref] ) {
-
-      const Exposure &ex = (*imgs[0])[ref];          
-      float ti = ex.ti;
-      
-      float Y_ref = (X[ref*3] + X[ref*3+1] + X[ref*3+2])/3.f;
-      const float noise_level = 0.01;      
-      float var_ref = (noise_level*noise_level)*Y_ref/ti;      // variance of the photon noise
-      
-      for( int i = 0 ; i < N ; i++ )
-      {
-
-        const Exposure &ex = (*imgs[0])[i];          
-        float ti = ex.ti;
-        
-        if( saturated_exp[i] ) {
-          skip_exp[i] = true;          
-          continue;
         }
+        skip_exp[i] = saturated_exp[i];      
+	  
+        float mw = (w[0][i] + w[1][i] + w[2][i])/3.f;
+        if( mw > best_mw && !saturated_exp[i] ) {
+          best_mw = mw;
+          ref = i;        
+        }      
+//      cerr << " ; ";      
+      }
+    	
+      // Deghosting
+      if( ref != -1 && !saturated_exp[ref] ) {
+
+        const Exposure &ex = (*imgs[0])[ref];          
+        float ti = get_exposure_compensation( ex );
+      
+        float Y_ref = (X[ref*3] + X[ref*3+1] + X[ref*3+2])/3.f;
+        const float noise_level = 0.01;      
+        float var_ref = (noise_level*noise_level)*Y_ref/ti;      // variance of the photon noise
+      
+        for( int i = 0 ; i < N ; i++ )
+        {
+
+          const Exposure &ex = (*imgs[0])[i];          
+          float ti = get_exposure_compensation( ex );
         
-        float rho = corr_vec3( &X[i*3], &X[ref*3] );
+          if( saturated_exp[i] ) {
+//          skip_exp[i] = true;          
+            continue;
+          }
+        
+          //continue; // Skip deghostig for now
+		
+          float rho = corr_vec3( &X[i*3], &X[ref*3] );
 //     float chroma = std::max( std::max( X[i*3], X[i*3+1] ), X[i*3+2] ) - std::min( std::min( X[i*3], X[i*3+1] ), X[i*3+2] );     
 //     cerr << rho << " - " << chroma << ", ";
 //        cerr << i << "(" << saturated_exp[i] << "): " << rho << endl;
 
-        float Y_exp = (X[i*3] + X[i*3+1] + X[i*3+2])/3.f;
-        float var_exp = (noise_level*noise_level)*Y_exp / ti;
+          float Y_exp = (X[i*3] + X[i*3+1] + X[i*3+2])/3.f;
+          float var_exp = (noise_level*noise_level)*Y_exp / ti;
 
-        float ci = 1.96 * sqrt(var_ref+var_exp);
+          float ci = 1.96 * sqrt(var_ref+var_exp);
         
-        skip_exp[i] = ( rho < 0.9 ) || fabs( Y_exp - Y_ref ) > ci;        
+          // Skip a frame if color correlation too low or difference to reference too high
+          skip_exp[i] = ( rho < 0.9 ) || fabs( Y_exp - Y_ref ) > ci;        
+          if( skip_exp[i] ) 
+            skipped_deghost++;
+        }
       }
-    }    
-
+    }
     
-    int skip_bits = 0;
     
-    for( int i = 0 ; i < N ; i++ ) {
+/*    int skip_bits = 0;
+    
+      for( int i = 0 ; i < N ; i++ ) {
 
       if( !skip_exp[i] )
-        skip_bits++; // |= (1<<i);
-    }
+      skip_bits++; // |= (1<<i);
+      }*/
     
 
     
 /*   for( int i = 0 ; i < N ; i++ ) {        
-      skip_exp[i] = false;
-      }*/
+     skip_exp[i] = false;
+     }*/
       
     
 //   cerr << endl;    
@@ -220,12 +235,12 @@ int robertson02_applyResponseRGB( pfs::Array2D *rgb_out[],
       // For each exposure
       for( int i = 0 ; i < N ; i++ )
       {
-        if( skip_exp[i] || saturated_exp[i] )
+        if( deghosting && (skip_exp[i] || saturated_exp[i]) )
           continue;
         
         const Exposure &ex = (*imgs[cc])[i];          
         int   m  = (int) (*ex.yi)( j );
-        float ti = ex.ti;        
+        float ti = get_exposure_compensation( ex );
 
         // Testing the noise-optimal approach
 /*        float iso2 = ex.iso*ex.iso;
@@ -234,8 +249,24 @@ int robertson02_applyResponseRGB( pfs::Array2D *rgb_out[],
           sum += w * resp_curve[cc][ m ] / ti;
           div += w;*/
         
-        sum += weights [ m ] * ew[i] * resp_curve[cc][ m ] / ti;
-        div += weights [ m ] * ew[i];
+//        float w = weights [ m ] * ew[i];
+//        sum += w * resp_curve[cc][ m ] / ti;
+//        div += w;
+
+//        const float noise_level = 0.01;      
+//        float var = (noise_level*noise_level)*resp_curve[cc][ m ]/(ti*ti);
+        
+//        float w = 1/var;
+//        float w = log(sqrt(resp_curve[cc][ m ] / ti / var))+3;
+//        float w = log(sqrt(m));
+        float w = weights [ m ] * ew[i];
+        
+        sum += w * resp_curve[cc][ m ] / ti;
+        div += w;
+
+        if( j < 10 && cc == 1 )
+          std::cerr << "j = " << j << " ;i = " << i << " ;w = " << w << std::endl;        
+        
         div2 += weights [ m ];        
       }
 
@@ -289,12 +320,12 @@ int robertson02_applyResponseRGB( pfs::Array2D *rgb_out[],
         int best_v = short_long == 1.f ? M-1 : 0;        
         for( int i = 0 ; i < N ; i++ )
 	{
-          if( skip_exp[i] )
+          if( deghosting && skip_exp[i] )
             continue;
           
           const Exposure &ex = (*imgs[cc])[i];          
 	  int   m  = (int) (*ex.yi)( j );
-	  float ti = ex.ti;          
+	  float ti = get_exposure_compensation( ex );;          
           if( ti*short_long < best_ti*short_long ) {            
             best_ti = ti;
             best_v = (int)(*ex.yi)(j);
@@ -307,6 +338,8 @@ int robertson02_applyResponseRGB( pfs::Array2D *rgb_out[],
     
     
   }
+  VERBOSE_STR << "Exposure pixels skipped due to deghosting: " << 
+    (float)skipped_deghost*100.f/(float)(width*height*N) << "%" << std::endl;
 
   return saturated_pixels;
   
