@@ -22,7 +22,7 @@
  *
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: pfsgamma.cpp,v 1.3 2008/07/29 16:14:29 rafm Exp $
+ * $Id: pfsgamma.cpp,v 1.4 2013/01/29 22:15:01 rafm Exp $
  */
 
 #include <config.h>
@@ -51,7 +51,7 @@ void printHelp()
     "See man page for more information.\n" );
 }
 
-void applyGammaOnFrames( int argc, char* argv[] )
+void retimeFrames( int argc, char* argv[] )
 {
   pfs::DOMIO pfsio;
 
@@ -172,7 +172,7 @@ void applyGamma( pfs::Array2D *array, const float exponent, const float multipli
 int main( int argc, char* argv[] )
 {
   try {
-    applyGammaOnFrames( argc, argv );
+    retimeFrames( argc, argv );
   }
   catch( pfs::Exception ex ) {
     fprintf( stderr, PROG_NAME " error: %s\n", ex.getMessage() );
