@@ -22,7 +22,7 @@
  *
  * @author Miloslaw Smyk, <thorgal@wfmh.org.pl>
  *
- * $Id: pfspanoramic.cpp,v 1.4 2010/02/18 11:27:03 rafm Exp $
+ * $Id: pfspanoramic.cpp,v 1.5 2014/04/05 22:04:12 rafm Exp $
  */
 
 #include <map>
@@ -43,6 +43,9 @@ class QuietException
 
 const double EPSILON=1e-7;
 
+const double PI = 3.1415926535897932384626433;
+const double ONE_PI = 0.31830988618379067154; // 1/PI
+
 static void errorCheck( bool condition, const char *string )
 {
     if( !condition ) {
@@ -93,9 +96,9 @@ class Vector3D
   }
 
   //TODO: optimize rotations by precomputing sines and cosines
-  Vector3D rotateX(double angle)
+  void rotateX(double angle)
   {
-    angle *= (M_PI / 180);
+    angle *= (PI / 180.);
 
     double c = cos(angle);
     double s = sin(angle);
@@ -107,9 +110,9 @@ class Vector3D
     z = z2;
   }
 
-  Vector3D rotateY(double angle)
+  void rotateY(double angle)
   {
-    angle *= (M_PI / 180);
+    angle *= (PI / 180.);
 
     double c = cos(angle);
     double s = sin(angle);
@@ -121,9 +124,9 @@ class Vector3D
     z = z2;
   }
 
-  Vector3D rotateZ(double angle)
+  void rotateZ(double angle)
   {
-    angle *= (M_PI / 180);
+    angle *= (PI / 180);
 
     double c = cos(angle);
     double s = sin(angle);
@@ -195,7 +198,7 @@ class ProjectionFactory
     {
       char *opts;
       
-      if(opts = strchr(name, '/'))
+      if( (opts = strchr(name, '/')) )
       {
         *opts++ = '\0';
       }
@@ -391,7 +394,7 @@ class AngularProjection : public Projection
     v *= totalAngle / 360;
 
     double phi = atan2( v, u );
-    double theta = M_PI * sqrt( u * u + v * v );
+    double theta = PI * sqrt( u * u + v * v );
 
     Vector3D *direction = new Vector3D(phi, theta);
     double t;
@@ -411,7 +414,7 @@ class AngularProjection : public Projection
     {
       double distance = sqrt(direction->x * direction->x + direction->y * direction->y);
 
-      double r = (1 / (2 * M_PI)) * acos(direction->z) / distance;
+      double r = (1 / (2 * PI)) * acos(direction->z) / distance;
 
       u = direction->x * r + 0.5;
       v = direction->y * r + 0.5;
@@ -472,7 +475,7 @@ class CylindricalProjection : public Projection
   {
     u = 0.75 - u;
 
-    u *= M_PI * 2;
+    u *= PI * 2;
 
     v = acos( 1 - 2 * v );
 
@@ -504,7 +507,7 @@ class CylindricalProjection : public Projection
         if(ratio > 1)
           ratio = 1;
 
-      double lon = acos(ratio) / (2 * M_PI);
+      double lon = acos(ratio) / (2 * PI);
 
       if(cross->dot(direction) < 0)
         u = lon;
@@ -572,8 +575,8 @@ class PolarProjection : public Projection
   {
     u = 0.75 - u;
 
-    u *= M_PI * 2;
-    v *= M_PI;
+    u *= PI * 2;
+    v *= PI;
 
     Vector3D *direction = new Vector3D(u, v);
 
@@ -589,7 +592,7 @@ class PolarProjection : public Projection
     double u, v;
     double lat = acos(direction->dot(pole));
 
-    v = lat * M_1_PI;
+    v = lat * ONE_PI;
 
     if(v < EPSILON || fabs(1 - v) < EPSILON)
       u = 0;
@@ -603,7 +606,7 @@ class PolarProjection : public Projection
         if(ratio > 1)
           ratio = 1;
 
-      double lon = acos(ratio) / (2 * M_PI);
+      double lon = acos(ratio) / (2 * PI);
 
       if(cross->dot(direction) < 0)
         u = lon;
@@ -924,7 +927,7 @@ void transformArray( const pfs::Array2D *in, pfs::Array2D *out, TransformInfo *t
             delete direction;
             delete p;
 
-            (*out)(x,y) = pixVal * scaler;
+            (*out)(x,y) = (float)(pixVal * scaler);
           }
       }
     }
