@@ -119,6 +119,10 @@ static pfs::ColorSpace findColorSpace( const char *name )
     else if( !strcasecmp( name, "SRGB" ) ) return pfs::CS_SRGB;
     else if( !strcasecmp( name, "YUV" ) ) return pfs::CS_YUV;
     else if( !strcasecmp( name, "YXY" ) ) return pfs::CS_Yxy;
+    else if( !strcasecmp( name, "RGB2020" ) ) return pfs::CS_RGB2020;
+    else if( !strcasecmp( name, "PQYCbCr2020" ) ) return pfs::CS_PQYCbCr2020;
+    else if( !strcasecmp( name, "HLGYCbCr2020") ) return pfs::CS_HLGYCbCr2020;
+    else if( !strcasecmp( name, "YCbCr709" ) ) return pfs::CS_YCbCr709;
 
     throw pfs::Exception( "Not recognized color space" );
 }
