@@ -20,7 +20,7 @@ if( nargin ~= 2 )
 end
 
 %cmd = sprintf( '%spfsout %s%s', pfs_shell(), fileName, pfs_shell(1) )
-fid = pfspopen( sprintf( '%spfsout ''%s''%s', pfs_shell(), fileName, pfs_shell(1) ), 'w' );    
+fid = pfspopen( sprintf( '%spfsout ''%s''%s', pfs_shell(), pfs_fix_path(fileName), pfs_shell(1) ), 'w' );    
 pfs = pfsopen( fid, size( img ) );
 
 pfs.channels.Y = img;
