@@ -3,7 +3,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#if defined( __win32__ )
+#include <config.h>
+
+#if defined(_WIN32) || defined(_WIN64) 
 #include <io.h>
 #include <process.h>
 #else
@@ -25,17 +27,13 @@ void mexFunction(int nlhs, mxArray *plhs[],
   if( mxGetN(prhs[0]) != 2 )
     mexErrMsgTxt( SCRIPT_NAME ": File descriptor not created with pfspopen." );
   
-  double *p_fid = mxGetPr( prhs[0] );
-//  int fid = (int)p_fid[0];
-  FILE *fh = (FILE*)((unsigned long)p_fid[1]);
+   double *p_fid = mxGetPr( prhs[0] );
 
-//  FILE *fh = fdopen( fid, "r" );
-  if( pclose( fh ) == -1 )
-    mexErrMsgTxt( SCRIPT_NAME ": pclose has failed.");
-
-//  int res = close( fid );
-//  if( res == -1 )
-//	mexErrMsgTxt( SCRIPT_NAME ": pclose has failed.");
+   // cast 64-bit number into a pointer   
+   FILE *fh  = (FILE*)*((unsigned long long*)(p_fid+1));
+  
+    if( pclose( fh ) == -1 )
+		mexErrMsgTxt( SCRIPT_NAME ": pclose has failed.");
   
   return;
 }
