@@ -25,7 +25,7 @@ void mexFunction(int nlhs, mxArray *plhs[],
   if( in == NULL ) {		
 	mexErrMsgTxt("popen has failed.");
   }
-
+  
   int fd = fileno( in );
 //  int fd = dup( fileno( in ) );
 //  if( fclose( in ) != 0 ) 
@@ -34,9 +34,9 @@ void mexFunction(int nlhs, mxArray *plhs[],
   plhs[0] = mxCreateNumericMatrix( 1, 2, mxDOUBLE_CLASS, mxREAL );
   double *df_ptr = (double*)mxGetData( plhs[0] );
   *df_ptr = fd;
-  // Very bad hack
-  df_ptr[1] = (unsigned long)in;
-
+  // Store the pointer as a 64-bit number, avoid type conversion
+  *((unsigned long long*)(df_ptr+1)) = (unsigned long long)in;
+  
   mxFree( cmd_line );
   mxFree( mode );
 
