@@ -186,7 +186,8 @@ void mexFunction(int nlhs, mxArray *plhs[],
     ctx.writeFrame( frame, fh );
     ctx.freeFrame( frame );
     fclose( fh );
-    fsync( fid );
+	
+    //fsync( fid );
 
   }
   catch( pfs::Exception ex )
