@@ -1,6 +1,6 @@
 function pfs_struct = pfs_open_frames( filePattern, frameSize )
   ## Open frames / image in one of the suppoted formats for reading or
-  ## writing. Reading or writting frames is donw with pfsput or pfsget.
+  ## writing. Reading or writing frames is done with pfsput or pfsget.
   ##
   ## usage: pfs_struct = pfs_open_frames( filePattern, size )
   ##        pfs_struct = pfs_open_frames( filePattern )
