@@ -74,9 +74,11 @@ DEFUN_DLD( pfsget, args, , helpString)
     return retval;    
   }
 
+  
   pfsStream.del( "channels" );
   pfsStream.del( "tags" );
   pfsStream.del( "channelTags" );
+
   
   try {
     pfs::DOMIO ctx;
@@ -90,7 +92,7 @@ DEFUN_DLD( pfsget, args, , helpString)
       // Set width and height
       {
         pfsStream.assign( "columns", octave_value(frame->getWidth()) );
-        pfsStream.assign( "rows", octave_value(frame->getHeight()) );
+        pfsStream.assign( "rows", octave_value(frame->getHeight()) ); 
       }
     
       // Add channels as matrices to pfs stream struct
@@ -107,10 +109,12 @@ DEFUN_DLD( pfsget, args, , helpString)
             for( int c = 0; c < ch->getCols(); c++ ) {
               mat(r,c) = (*ch)(index++);
             }      
-      
+
           channels.assign( ch->getName(), mat );
+          
         }
-        pfsStream.assign( "channels", channels );
+        pfsStream.assign( "channels", octave_value(channels) );
+        
       }
 
       //Add tags
@@ -122,7 +126,8 @@ DEFUN_DLD( pfsget, args, , helpString)
           const char *tagName = it->getNext();         
           tags.assign( tagName, octave_value( frame->getTags()->getString( tagName )) );
         }
-        pfsStream.assign( "tags", tags );
+        
+        pfsStream.assign( "tags", octave_value(tags) );
         
         octave_scalar_map channelTagList;
 
@@ -138,16 +143,15 @@ DEFUN_DLD( pfsget, args, , helpString)
             const char *tagName = tit->getNext();
             channelTags.assign( tagName, octave_value(ch->getTags()->getString( tagName )) );
           }
-          channelTagList.assign( ch->getName(), channelTags );
+          channelTagList.assign( ch->getName(), octave_value(channelTags) );
         }        
-        pfsStream.assign( "channelTags", channelTagList );
+        pfsStream.assign( "channelTags", octave_value(channelTagList) );
         
       }
       
     
     }
-    ctx.freeFrame( frame );
-
+    ctx.freeFrame( frame );    
   }
   catch( pfs::Exception ex )
   {
@@ -157,7 +161,6 @@ DEFUN_DLD( pfsget, args, , helpString)
   }
 //    if( fh != stdin ) fclose( fh );    
     
-  retval.append(pfsStream);
-    
+  retval.append(pfsStream);  
   return retval;
 }
