@@ -52,7 +52,7 @@ DEFUN_DLD( pfsput, args, , helpString)
     return retval;
   }
   
-  octave_scalar_map pfsStream = args(0).map_value();
+  octave_map pfsStream = args(0).map_value();
 
   octave_scalar_map::const_iterator itFH = pfsStream.seek( "FH" );
   if( itFH == pfsStream.end() ||
@@ -94,7 +94,7 @@ DEFUN_DLD( pfsput, args, , helpString)
   }
 
   // Get channels
-  octave_scalar_map channels;
+  octave_map channels;
   {
     octave_scalar_map::const_iterator itChannels = pfsStream.seek( "channels" );
     if( itChannels == pfsStream.end() ||
@@ -142,7 +142,7 @@ DEFUN_DLD( pfsput, args, , helpString)
           throw pfs::Exception( "'tags' field must be a structure" );  
         }
         
-        octave_scalar_map_map tags = pfsStream.contents( itTags )(0).map_value();
+        octave_map tags = pfsStream.contents( itTags )(0).map_value();
         for( octave_scalar_map::iterator itTag = tags.begin(); itTag != tags.end(); itTag++ ) {
           std::string tagName = tags.key(itTag);
 
@@ -162,7 +162,7 @@ DEFUN_DLD( pfsput, args, , helpString)
         {
           throw pfs::Exception( "'channelTags' field must be a structure" );  
         }
-        octave_scalar_map tagChannels = pfsStream.contents( itChTags )(0).map_value();
+        octave_map tagChannels = pfsStream.contents( itChTags )(0).map_value();
         for( octave_scalar_map::iterator itCh = tagChannels.begin(); itCh != tagChannels.end(); itCh++ ) {
           std::string channelName = tagChannels.key(itCh);
           if( !tagChannels.contents( itCh )(0).is_map() ) {
@@ -173,7 +173,7 @@ DEFUN_DLD( pfsput, args, , helpString)
             throw pfs::Exception( "can not set channel tag if channel is missing" );
           }
           
-          octave_scalar_map tags = tagChannels.contents( itCh )(0).map_value();
+          octave_map tags = tagChannels.contents( itCh )(0).map_value();
           for( octave_scalar_map::iterator itTag = tags.begin(); itTag != tags.end(); itTag++ ) {
             std::string tagName = tags.key(itTag);
             if( !tags.contents( itTag )(0).is_string() ) 
