@@ -513,10 +513,20 @@ static void readTags( TagContainerImpl *tags, FILE *in )
   if( readItems != 1 || tagCount < 0 || tagCount > 1024 )
     throw Exception( "Corrupted PFS tag section: missing or wrong number of tags" );
 
-  char buf[MAX_TAG_STRING+1];
+  char buf[MAX_TAG_STRING];
   for( int i = 0; i < tagCount; i++ ) {
     char *read = fgets( buf, MAX_TAG_STRING, in );
     if( read == NULL ) throw Exception( "Corrupted PFS tag section: missing tag" );
+    if( strlen(buf)==(MAX_TAG_STRING-1) ) { // Crop the string if needed
+      buf[MAX_TAG_STRING-2] = PFSEOLCH;
+      // now we need to skip all characters in the file stream up to EOL
+      const int SKIP_BUF_LEN = 256;
+      char skip_buf[SKIP_BUF_LEN];
+      do {
+	read = fgets( skip_buf, SKIP_BUF_LEN, in );
+      } while( read != NULL && strlen(skip_buf)==(SKIP_BUF_LEN-1) );
+
+    }
     char *equalSign = strstr( buf, "=" );
     if( equalSign == NULL ) throw Exception( "Corrupted PFS tag section ('=' sign missing)" );
     tags->appendTagEOL( buf );
