@@ -29,6 +29,8 @@
 #include <getopt.h>
 #include <stdlib.h>
 #include <list>
+#include <string>
+#include <sstream>
 
 #include "pfs.h"
 
@@ -39,6 +41,30 @@ using namespace std;
 namespace pfs
 {
 
+string getColorspaceString(ColorSpace cs){
+  switch(cs){
+    case CS_XYZ:
+      return "XYZ"; 
+    case CS_RGB:
+      return "RGB";     
+    case CS_SRGB:
+        return "sRGB";    
+    case CS_PQYCbCr2020:
+        return "PQ YCbCr 2020";
+    case CS_YCbCr709:
+        return "YCbCr BT.709"; 
+    case CS_HLGYCbCr2020:
+        return "HLG YCbCr 2020";
+    case CS_RGB2020:
+        return "RGB2020";
+  }
+}
+
+string intToString(int a){
+  stringstream ss;
+  ss << a;
+  return ss.str();
+}
 static void removeCommandLineArg( int &argc, char* argv[],
   int firstArgToRemove, int numArgsToRemove = 1 );
 
@@ -73,6 +99,8 @@ struct FilePattern
 
 class FrameFileIteratorImpl
 {
+  
+protected:
   char *pattern;
   const char *fopenMode;
 
