@@ -105,6 +105,7 @@ PFSViewWidget::PFSViewWidget( QWidget *parent ) :
   updateMappingRequested( true ), clippingMethod(CLIP_SIMPLE)
 {
 
+  fit_to_content_mode = true;  
   setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
   
   
@@ -154,16 +155,18 @@ void PFSViewWidget::setFrame( pfs::Frame *frame )
     visibleChannel = frame->getChannel( visibleChannel )->getName(); 
   }
 
-  int desktopWidth, desktopHeight;
-  desktopWidth = QApplication::desktop()->width();
-  desktopHeight = QApplication::desktop()->height();
-  if( frame->getWidth() > desktopWidth ||
+  if( fit_to_content_mode ) {    
+    int desktopWidth, desktopHeight;
+    desktopWidth = QApplication::desktop()->width();
+    desktopHeight = QApplication::desktop()->height();
+    if( frame->getWidth() > desktopWidth ||
       frame->getHeight() > desktopHeight ) {
-    zoom = min( (float)desktopWidth / (float)frame->getWidth(),
-      (float)desktopHeight / (float)frame->getHeight() );
+      zoom = min( (float)desktopWidth / (float)frame->getWidth(),
+        (float)desktopHeight / (float)frame->getHeight() );
+    }  
   }
-  
   updateZoom();
+  
   setPointer();  
 }
 
@@ -627,6 +630,7 @@ void PFSViewWidget::zoomIn()
 {
   if( zoom >= 10 ) return;
   zoom *= 1.25f;
+  fit_to_content_mode = false;  
   updateZoom();
 }
 
@@ -635,12 +639,14 @@ void PFSViewWidget::zoomOut()
 {
   if( zoom <= 0.05 ) return;
   zoom *= 0.8f;
+  fit_to_content_mode = false;  
   updateZoom();
 }
 
 void PFSViewWidget::zoomOriginal()
 {
   zoom = 1;
+  fit_to_content_mode = false;  
   updateZoom();  
 }
 
