@@ -228,7 +228,7 @@ void compute_gaussian_level( const int width, const int height, const pfstmo::Ar
 
   const int kernel_len = 5;
   const int kernel_len_2 = kernel_len/2;
-  float kernel[kernel_len] = { 0.25 - kernel_a/2, 0.25 , kernel_a, 0.25, 0.25 - kernel_a/2 };
+  float kernel[kernel_len] = { 0.25f - kernel_a/2, 0.25f , kernel_a, 0.25f, 0.25f - kernel_a/2 };
 
   int step = 1<<level;
 
